.. Automatically generated by nengo-bones, do not edit this file directly

******************
Nengo contributors
******************

See https://github.com/nengo/nengo/graphs/contributors
for a list of the people who have committed to Nengo.
Thank you for your contributions!
